# Deploy tasks and helpers for application

[![Build Status](https://readthedocs.org/projects/roy/badge/?version=latest&style=flat)](https://readthedocs.org/projects/roy)
[![Docs Build Status](https://travis-ci.org/royprojectcom/roy.svg?branch=master)](https://travis-ci.org/royprojectcom/roy)
[![Maintainability](https://api.codeclimate.com/v1/badges/d55631dca90a900ce134/maintainability)](https://codeclimate.com/github/royprojectcom/roy/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/d55631dca90a900ce134/test_coverage)](https://codeclimate.com/github/royprojectcom/roy/test_coverage)
[![Requirements Status](https://requires.io/github/royprojectcom/roy/requirements.svg?branch=master)](https://requires.io/github/royprojectcom/roy/requirements/?branch=master)
[![PyPI implementation](https://img.shields.io/pypi/implementation/roy.svg)](https://pypi.python.org/pypi/roy/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/roy.svg)](https://pypi.python.org/pypi/roy/)
[![PyPI license](https://img.shields.io/pypi/l/roy.svg)](https://pypi.python.org/pypi/roy/)
[![PyPI version](https://badge.fury.io/py/roy.svg)](https://pypi.python.org/pypi/roy/)
[![PyPI downloads per month](https://img.shields.io/pypi/dm/roy.svg)](https://pypi.python.org/pypi/unv_)

## Set of libs to simplify deploy configuration into app settings
